-- Note: this Mixin is a little bit special, it adds both a function in the core and others in the button mixin

function FlexBar2:RegisterTextSub(Name, Triggers, Func) -- The core part of RegisterTextSub (pretty short)
	if(type(self.TextSubs) ~= "table") then
		self.TextSubs = {};
	end
	if(type(self.TextSubs[Triggers]) ~= "table") then
		self.TextSubs[Triggers] = {};
	end
	self.TextSubs[Triggers][Name] = Func;
end

local TextSubs = FlexBar2.OO.Mixin 
{
	"RegisterTextSub", -- The button specific part of RegisterTextSub
	"UpdateTextSub", -- Update certain subs depending on what event triggered this
	"SetTextSub", -- Set the text of a sub
};


function TextSubs:Activate()
	self.Frame.Text1 = self.Frame:CreateFontString(nil, "ARTWORK", "NumberFontNormal"):SetJustifyH("LEFT"):SetPoint("TOPLEFT", self.Frame, "TOPLEFT");
	self.Frame.Text2 = self.Frame:CreateFontString(nil, "ARTWORK", "NumberFontNormal"):SetJustifyH("RIGHT"):SetPoint("TOPRIGHT", self.Frame, "TOPRIGHT");
	self.Frame.Text3 = self.Frame:CreateFontString(nil, "ARTWORK", "NumberFontNormal"):SetJustifyH("RIGHT"):SetPoint("BOTTOMRIGHT", self.Frame, "BOTTOMRIGHT");
	self.Frame.Text4 = self.Frame:CreateFontString(nil, "ARTWORK", "NumberFontNormal"):SetJustifyH("LEFT"):SetPoint("BOTTOMLEFT", self.Frame, "BOTTOMLEFT");
	self.Frame.Text5 = self.Frame:CreateFontString(nil, "ARTWORK", "NumberFontNormal"):SetJustifyH("CENTER"):SetPoint("CENTER");
	self:RegisterTextSubs();
	if(type(self.Settings.TextSubs) == "table") then
		for n,v in ipairs(self.Settings.TextSubs) do
			self:SetTextSub(n, v);
		end
	end
end

function TextSubs:RegisterTextSubs()
	for Triggers, Name in pairs(FlexBar2.TextSubs) do
		if(type(Triggers) == "string") then
			self:RegisterEvent(Triggers, "UpdateTextSubs");
		elseif(type(Triggers) == "table") then
			for n,v in ipairs(Triggers) do
				self:RegisterEvent(v, "UpdateTextSubs");
			end
		else
			return false;
		end
	end
end

function TextSubs:UpdateTextSub(Event)
	
end

function TextSubs:SetTextSub(Field, Text, Save)
	if(type(self.TextSubs) ~= "table") then
		self.TextSubs = {};
	end
	if(type(self.TextSubs[Field]) ~= "table") then
		self.TextSubs[Field] = {};
	end
	local PrefixList, SuffixList;
	for Match in string.gmatch(Text, "$%((.-)%)") do
		local _, _, Prefix, Suffix = string.find(Match, "(%a*) ?(.*)");
		table.insert(PrefixList, Prefix);
		table.insert(SuffixList, Suffix);
	end
	self.TextSubs[Field].Text = Text;
	self.TextSubs[Field].PrefixList = PrefixList;
	self.TextSubs[Field].SuffixList = SuffixList;
	if(Save) then
		if(type(self.Settings.TextSubs) ~= "table") then
			self.Settings.TextSubs = {};
		end
		self.Settings.TextSubs[Field] = Text;
	end
end


FlexBar2:RegisterButtonClass(TextSubs);
